@@ -208,6 +208,7 @@ def _templated(entry, template, keep_multiple=False):
 
 
 def setup_t_grid(trajectory, t_grid, offset=True):
+    # TODO: document this crucial piece of crap
     # First get all possible time differences
     steps = trajectory.steps
     off_samp = {}
@@ -215,6 +216,7 @@ def setup_t_grid(trajectory, t_grid, offset=True):
         offset_range = range(trajectory.block_size)
     else:
         offset_range = [0]
+
     for off in offset_range:
         for i in range(off, len(steps)-off):
             if steps[i] - steps[off] not in off_samp:
@@ -223,7 +225,7 @@ def setup_t_grid(trajectory, t_grid, offset=True):
     # Retain only those pairs of offsets and sample
     # difference that match the desired input. This is the grid
     # used internally to calculate the time correlation function.
-    i_grid = set([int(round(t/trajectory.timestep)) for t in t_grid])
+    i_grid = {int(round(t/trajectory.timestep)) for t in t_grid}
     offsets = [off_samp[t] for t in _templated(sorted(off_samp.keys()), sorted(i_grid))]
     return offsets
 
